uhugo.post_install.providers.vercel — uHugo 1.1.10 documentation

# uhugo.post_install.providers.vercel

class uhugo.post_install.providers.vercel.Vercel(api_key: str = None, config_path: str = None, hugo_version: str = None)

  Vercel provider

  Parameters:

    - hugo_version – New Hugo version

    - api_key – Authentication key for providers

    - config_path – Path for configuration file of the provider

  update_api(key: str)

    Updates Cloudflare Pages environment variable of `HUGO_VERSION`.

    Parameters:

      key – API key

    Returns:

  update_config_file(file_name: str)

    Updates `vercel.json` file with Hugo’s version

    Parameters:

      file_name – Path of `vercel.json`

    Returns: